pyRBM.Build
===================
Description
===================

The pyRBM.Build module enables the programmatic creation of Classes, Locations and Rules.

Once all the model objects of one type are created, they should be added to the corresponding plural class (i.e. all Rule objects should be added a Rules object via )


Classes
--------------------------

.. automodule:: pyRBM.Build.Classes
   :members:
   :undoc-members:
   :show-inheritance:

Locations
----------------------------

.. automodule:: pyRBM.Build.Locations
   :members:
   :undoc-members:
   :show-inheritance:

RuleMatching
-------------------------------

.. automodule:: pyRBM.Build.RuleMatching
   :members:
   :undoc-members:
   :show-inheritance:

RuleTemplates
--------------------------------

.. automodule:: pyRBM.Build.RuleTemplates
   :members:
   :undoc-members:
   :show-inheritance:

Rules
------------------------

.. automodule:: pyRBM.Build.Rules
   :members:
   :undoc-members:
   :show-inheritance:

Utils
------------------------

.. automodule:: pyRBM.Build.Utils
   :members:
   :undoc-members:
   :show-inheritance: